pub struct GamepadId(/* private fields */);Expand description
Gamepad ID.
It’s not possible to create an instance of this type directly, but you can obtain one from a Gamepad
handle or any event. ID is valid for the entire lifetime of the Gilrs context.